@@ -112,9 +112,6 @@ class Field(object):
     def __str__(self):
         return str(self.getName())
 
-    def __repr__(self):
-        return str(self.getName())
-
     ## Functions
     def addVisualizationFunction(self, function):
         self.visualizationFunctions.append(function)
@@ -640,7 +637,7 @@ class Field(object):
         logging.debug("Concat field from {0} to {1}".format(self.getName(), lastField.getName()))
 
         # If no last field is provided we stop here
-        if lastField == None:
+        if lastField is None:
             msg = "Last field is not provided."
             return (False, msg)
 
@@ -680,6 +677,19 @@ class Field(object):
         except IndexError:
             return None
 
+    def getPreviousFieldInCurrentLayer(self):
+        """getPreviousFieldInCurrentLayer:
+        Computes and returns the previous field declared
+        on the same layer. It returns None if it doesn't exist"""
+        parentField = self.getParentField()
+        localFields = parentField.getLocalFields()
+        indexField1 = localFields.index(self)
+        indexField2 = indexField1 - 1
+        try:
+            return localFields[indexField2]
+        except IndexError:
+            return None
+
     #+----------------------------------------------
     #| concatWithNextField:
     #|  Concatenate the current field with the next one at the same level
@@ -833,7 +843,7 @@ class Field(object):
                 value = value[1:len(value) - 1]
 
             value = TypeConvertor.netzobRawToBitArray(value)
-            variable = DataVariable(str(uuid.uuid4()), self.getName(), False, False, BinaryType(True, len(value), len(value)), value.to01())  # A static field is neither mutable nor random.
+            variable = DataVariable(str(uuid.uuid4()), "Default variable of {0}".format(self.getName()), False, False, BinaryType(True, len(value), len(value)), value.to01())  # A static field is neither mutable nor random.
             return variable
         else:
             if self.defaultVariable is None:
@@ -849,19 +859,25 @@ class Field(object):
                 @rtype: netzob.Common.MMSTD.Dictionary.Variables.AggregateVariable.AggregateVariable
                 @return: the generated variable
         """
-        # The default variable is an alternative of all the possibilities (in binary type)
-        cells = self.getUniqValuesByField()
-        tmpDomain = set()
-        for cell in cells:
-            tmpDomain.add(TypeConvertor.netzobRawToBitArray(cell))
-        domain = sorted(tmpDomain)
+        variable = None
+        if self.isStatic():
+            # The default variable is simple DataVariable (in binary type)
+            data = TypeConvertor.netzobRawToBitArray(self.getRegexData())
+            variable = DataVariable(str(uuid.uuid4()), "Default variable", False, False, BinaryType(True, len(data), len(data)), data.to01())
+        else:
+            # The default variable is an alternative of all the possibilities (in binary type)
+            cells = self.getUniqValuesByField()
+            tmpDomain = set()
+            for cell in cells:
+                tmpDomain.add(TypeConvertor.netzobRawToBitArray(cell))
+            domain = sorted(tmpDomain)
 
-        variable = AggregateVariable(str(uuid.uuid4()), "Aggregate", False, False, None)
-        alternateVar = AlternateVariable(str(uuid.uuid4()), "Alternate", True, False, None)
-        for d in domain:
-            child = DataVariable(str(uuid.uuid4()), "defaultVariable", False, False, BinaryType(True, len(d), len(d)), d.to01())
-            alternateVar.addChild(child)
-        variable.addChild(alternateVar)
+            variable = AlternateVariable(str(uuid.uuid4()), "Default variable of {0}".format(self.getName()), True, False, None)
+            i = 0
+            for d in domain:
+                child = DataVariable(str(uuid.uuid4()), "Default child variable {0}".format(i), False, False, BinaryType(True, len(d), len(d)), d.to01())
+                i += 1
+                variable.addChild(child)
         return variable
 
     ## Fields
@@ -921,7 +937,7 @@ class Field(object):
         else:
             self.fields.pop(index)
 
-    def removeEmptyFields(self, cb_status):
+    def removeEmptyFields(self, cb_status=None):
         """
         removeEmptyFields: we look for useless fields (i.e. fields
         that produces only empty cells) and remove them.
@@ -941,7 +957,20 @@ class Field(object):
                 # Concatenate the current useless inner field with the next field
                 fieldsToRemove.append(innerField)
         for field in fieldsToRemove:
+            # compute if the remaining fields aroung deleted one need to be merged
+            doConcat = False
+            # retrieve next and previous field and if there are both static
+            # or both dynamic we concat them
+            previousField = field.getPreviousFieldInCurrentLayer()
+            if previousField is not None:
+                nextField = field.getNextFieldInCurrentLayer()
+                if nextField is not None:
+                    # both static
+                    if previousField.isStatic() == nextField.isStatic():
+                        doConcat = True
             field.getParentField().removeLocalField(field)
+            if doConcat:
+                previousField.concatWithNextField()
 
     def removeLocalField(self, field):
         """removeLocalField:
@@ -1340,7 +1369,7 @@ class Field(object):
                 xmlInnerFields = xmlRoot.find("{" + namespace + "}fields")
                 for xmlInnerField in xmlInnerFields.findall("{" + namespace + "}field"):
                     innerField = Field.loadFromXML(xmlInnerField, namespace, version, symbol)
-                    if innerField != None:
+                    if innerField is not None:
                         field.addField(innerField)
 
             return field
