@@ -36,6 +36,7 @@ import re
 from lxml.etree import ElementTree
 from lxml import etree
 import shutil
+import uuid
 
 
 #+---------------------------------------------------------------------------+
@@ -107,9 +108,20 @@ def loadWorkspace_0_1(workspacePath, workspaceFile):
             if function is not None:
                 workspace.addCustomTransformationFunction(function)
 
+    enableBugReporting = False
+    if xmlWorkspaceConfig.find("{" + WORKSPACE_NAMESPACE + "}enable_bug_reporting") is not None and xmlWorkspaceConfig.find("{" + WORKSPACE_NAMESPACE + "}enable_bug_reporting").text is not None and len(xmlWorkspaceConfig.find("{" + WORKSPACE_NAMESPACE + "}enable_bug_reporting").text) > 0:
+        val = xmlWorkspaceConfig.find("{" + WORKSPACE_NAMESPACE + "}enable_bug_reporting").text
+        if val == "true":
+            enableBugReporting = True
+    workspace.setEnableBugReporting(enableBugReporting)
+
     return workspace
 
 
+class WorkspaceException(Exception):
+    pass
+
+
 class Workspace(object):
     """Class definition of a Workspace"""
 
@@ -124,17 +136,18 @@ class Workspace(object):
     #| Constructor
     #| @param path : path of the workspace
     #+-----------------------------------------------------------------------+
-    def __init__(self, name, creationDate, path, pathOfTraces, pathOfLogging, pathOfPrototypes, lastProjectPath=None, importedTraces=[]):
+    def __init__(self, name, creationDate, path, pathOfTraces, pathOfLogging, pathOfPrototypes, lastProjectPath=None, importedTraces={}):
         self.name = name
-        self.path = path
+        self.path = os.path.abspath(path)
         self.creationDate = creationDate
         self.projects_path = []
-        self.pathOfTraces = pathOfTraces
-        self.pathOfLogging = pathOfLogging
-        self.pathOfPrototypes = pathOfPrototypes
+        self.pathOfTraces = os.path.join(self.path, pathOfTraces)
+        self.pathOfLogging = os.path.join(self.path, pathOfLogging)
+        self.pathOfPrototypes = os.path.join(self.path, pathOfPrototypes)
         self.lastProjectPath = lastProjectPath
         self.importedTraces = importedTraces
         self.customTransformationFunctions = []
+        self.enableBugReporting = False
 
     def getNameOfProjects(self):
         nameOfProjects = []
@@ -162,19 +175,94 @@ class Workspace(object):
         project = Project.loadProject(self, self.lastProjectPath)
         return project
 
+    def setEnableBugReporting(self, enable):
+        self.enableBugReporting = enable
+
     def referenceLastProject(self, lastProject):
         self.lastProjectPath = lastProject
 
     def getImportedTraces(self):
-        return self.importedTraces
+        return self.importedTraces.values()
+
+    def getImportedTrace(self, traceId):
+        """Retrieve a specific trace, which identifier is traceId."""
+
+        try:
+            return self.importedTraces[traceId]
+        except KeyError:
+            raise WorkspaceException("Unable to find the requested trace ({0})".format(traceId))
 
     def addImportedTrace(self, importedTrace):
-        self.importedTraces.append(importedTrace)
-#        self.saveConfigFile()
+        self.importedTraces.update({importedTrace.id: importedTrace})
 
     def removeImportedTrace(self, importedTrace):
-        self.importedTraces.remove(importedTrace)
-#        self.saveConfigFile()
+        ImportedTrace.deleteTrace(importedTrace, self.pathOfTraces)
+        self.importedTraces.pop(importedTrace.id)
+
+    def newEmptyImportedTrace(self, name, description=""):
+        """This function is in charge of creating an empty
+        `ImportedTrace`.
+
+        :param name: 'name' of the new trace.
+        :param description (optional): description of the new
+        trace."""
+
+        newTrace = ImportedTrace(str(uuid.uuid4()),
+                                 datetime.datetime.now(),
+                                 "UNKNOWN",
+                                 description,
+                                 name)
+
+        self.addImportedTrace(newTrace)
+
+        return newTrace
+
+    def mergeImportedTraces(self, traceIds, name, keep=True):
+        """This methods allows to merge multiple traces. The merged
+        traces gets a new unique id.
+
+        If the 'keep' parameter is True, a copy of the initial traces
+        is kept.
+
+        We retrieve the 'ImportedTrace' object from its ID. Then we
+        merge all traces' messages and sessions into a new
+        'ImportedTrace'."""
+
+        messages = {}
+        sessions = {}
+        names = []
+        types = []
+
+        for traceId in traceIds:
+            trace = self.getImportedTrace(traceId)
+
+            messages.update(trace.messages)
+            sessions.update(trace.sessions)
+            names.append("'{0}'".format(trace.name))
+
+            # If the type is already a multiple type merge, types are
+            # comma separated values.
+            types.extend(trace.type.split(";"))
+
+            if keep is False:
+                self.removeImportedTrace(trace)
+
+        # The type of the new trace is a list of the multiple types of
+        # the traces to be merged.
+        newTraceType = "{0}".format(";".join(set(types)))
+        description = "Merge of traces {0} and {1}".format(', '.join(names[:-1]), names[-1])
+
+        newTrace = ImportedTrace(str(uuid.uuid4()),
+                                 datetime.datetime.now(),
+                                 newTraceType,
+                                 description,
+                                 name)
+        newTrace.messages = messages
+        newTrace.sessions = sessions
+
+        self.addImportedTrace(newTrace)
+
+        return newTrace
 
     def getTransformationFunctions(self):
         """Computes and returns the list of available functions"""
@@ -209,7 +297,23 @@ class Workspace(object):
         else:
             logging.warn("The project declared in {0} is already referenced in the workspace.". format(path))
 
-    def saveConfigFile(self):
+    def dereferenceProject(self, project_path):
+        if not project_path in self.projects_path:
+            raise WorkspaceException("The project '{0}' is not declared in the workspace".format(project_path))
+
+        self.projects_path.remove(project_path)
+
+    def saveConfigFile(self, overrideTraces=[]):
+        """This functions allows to save the current (and only)
+        instance of the Workspace. You can supply a list of traces
+        that should be written on-disk through the `overrideTraces`
+        variable. This allows to override specific traces that where
+        modified.
+
+        :param overrideTraces: a list of trace identifiers that should
+        be written on-disk, even if they already exists.
+        """
+
         workspaceFile = os.path.join(self.path, Workspace.CONFIGURATION_FILENAME)
 
         logging.info("Save the config file of the workspace {0} in {1}".format(self.getName(), workspaceFile))
@@ -235,6 +339,9 @@ class Workspace(object):
         xmlPrototypes = etree.SubElement(xmlWorkspaceConfig, "{" + WORKSPACE_NAMESPACE + "}prototypes")
         xmlPrototypes.text = str(self.getPathOfPrototypes())
 
+        xmlPrototypes = etree.SubElement(xmlWorkspaceConfig, "{" + WORKSPACE_NAMESPACE + "}enable_bug_reporting")
+        xmlPrototypes.text = str(self.enableBugReporting).lower()
+
         xmlWorkspaceProjects = etree.SubElement(root, "{" + WORKSPACE_NAMESPACE + "}projects")
         for projectPath in self.getProjectsPath():
             xmlProject = etree.SubElement(xmlWorkspaceProjects, "{" + WORKSPACE_NAMESPACE + "}project")
@@ -242,14 +349,20 @@ class Workspace(object):
 
         xmlWorkspaceImported = etree.SubElement(root, "{" + WORKSPACE_NAMESPACE + "}traces")
         for importedTrace in self.getImportedTraces():
-            importedTrace.save(xmlWorkspaceImported, WORKSPACE_NAMESPACE, COMMON_NAMESPACE, os.path.join(self.path, self.getPathOfTraces()))
+            # overrideTraces variable contains the list of
+            # ImportedTraces that should be overriden. This is useful
+            # in case of message removal for example.
+            forceOverride = (importedTrace.id in overrideTraces)
+
+            importedTrace.save(xmlWorkspaceImported, WORKSPACE_NAMESPACE, COMMON_NAMESPACE,
+                               os.path.join(self.path, self.getPathOfTraces()), forceOverride)
 
         xmlWorkspaceFunctions = etree.SubElement(root, "{" + WORKSPACE_NAMESPACE + "}functions")
         for function in self.getCustomFunctions():
             function.save(xmlWorkspaceFunctions, WORKSPACE_NAMESPACE)
 
         tree = ElementTree(root)
-        tree.write(workspaceFile)
+        tree.write(workspaceFile, pretty_print=True)
 
     @staticmethod
     def createWorkspace(name, path):
@@ -314,7 +427,7 @@ class Workspace(object):
             # If we find a version which validates the XML, we parse with the associated function
             if Workspace.isSchemaValidateXML(xmlSchemaPath, workspaceFile):
                 return None
-        return _("The specified workspace is not valid according the XSD definitions.")
+        return _("The specified workspace is not valid according to the XSD definitions.")
 
     @staticmethod
     def loadWorkspace(workspacePath):
@@ -322,12 +435,12 @@ class Workspace(object):
         provided directory
         @type workspacePath: str
         @var workspacePath: folder to load as a workspace
-        @return a workspace or None if not valid"""
+        @return a tupple with the workspace or None if not valid and the error message"""
 
         errorMessage = Workspace.isFolderAValidWorkspace(workspacePath)
         if errorMessage is not None:
             logging.warn(errorMessage)
-            return None
+            return (None, errorMessage)
 
         workspaceFile = os.path.join(workspacePath, Workspace.CONFIGURATION_FILENAME)
         logging.debug("  Workspace configuration file found: " + str(workspaceFile))
@@ -341,11 +454,11 @@ class Workspace(object):
                 parsingFunc = Workspace.WORKSPACE_SCHEMAS[xmlSchemaFile]
                 workspace = parsingFunc(workspacePath, workspaceFile)
                 if workspace is not None:
-                    return workspace
+                    return (workspace, None)
             else:
                 logging.fatal("The specified Workspace file is not valid according to the XSD found in %s." % (xmlSchemaPath))
 
-        return None
+        return (None, _("An unknown error prevented to open the workspace."))
 
     @staticmethod
     def isSchemaValidateXML(schemaFile, xmlFile):
