@@ -34,9 +34,6 @@ import os
 import logging
 import gettext
 import locale
-import uuid
-import shutil
-from lxml.etree import ElementTree
 
 #+---------------------------------------------------------------------------+
 #| Related third party imports
@@ -59,15 +56,19 @@ from netzob.NetzobMainView import NetzobMainView
 from netzob.Common.Project import Project
 from netzob.UI.Common.AboutDialog import AboutDialog
 from netzob.UI.Common.Controllers.BugReporterController import BugReporterController
+from netzob.UI.Common.Controllers.WorkspaceConfigurationController import WorkspaceConfigurationController
+from netzob.UI.Common.Controllers.ProjectPropertiesController import ProjectPropertiesController
+from netzob.UI.Common.Controllers.ProjectImportController import ProjectImportController
+from netzob.UI.Common.Controllers.ProjectExportController import ProjectExportController
 from netzob.UI.NetzobWidgets import NetzobErrorMessage
-from netzob.UI.WorkspaceSelector import WorkspaceSelector
+from netzob.UI.Common.Controllers.WorkspaceSelectorController import WorkspaceSelectorController
 from netzob.Common.Plugins.Extensions.ExportMenuExtension import ExportMenuExtension
 from netzob.UI.Common.Controllers.AvailablePluginsController import AvailablePluginsController
 from netzob.UI.Export.Controllers.RawExportController import RawExportController
 
 
 class NetzobMainController(object):
-    """"Netzob main window controller"""
+    """Netzob main window controller"""
 
     def __init__(self):
         # Parse command line arguments
@@ -75,9 +76,31 @@ class NetzobMainController(object):
         cmdLine.parse()
         opts = cmdLine.getOptions()
 
-        # Initialize everything
-        self._loadBugReporter(opts)
-        self.currentWorkspace = self._loadWorkspace(opts)
+        # Current workspace path can be provided in command line argument
+        if opts.workspace is None:
+            workspaceDir = ResourcesConfiguration.getWorkspaceDir()
+        else:
+            workspaceDir = opts.workspace
+
+        # Start the workspace management
+        self.workspaceSelectorController = WorkspaceSelectorController(self)
+        self.currentWorkspace = self.workspaceSelectorController.getWorkspace(workspaceDir)
+
+        if self.currentWorkspace is None:
+            sys.exit()
+
+        #self.currentWorkspace = self._loadWorkspace(opts)
+        self.currentProjet = None
+
+        # Enable bug reporting, if workspace is configured so or if
+        # netzob was explicitly started with the "-b" command line
+        # option.
+        enableBugReports = self.currentWorkspace.enableBugReporting
+        if enableBugReports != opts.bugReport:
+            enableBugReports = opts.bugReport
+        self.enableBugReporter(enableBugReports)
+
+        # Initialize everything else
         self._initLogging(opts)
         self._initResourcesAndLocales()
 
@@ -111,12 +134,11 @@ class NetzobMainController(object):
         # Refresh list of available projects
         self.updateListOfAvailableProjects()
 
-    def _loadBugReporter(self, opts):
-        """Activate the bug reporter if the command line options
-        requests it"""
+    def enableBugReporter(self, enable):
+        """Enable or disable the bug reporter."""
 
-        if opts.bugReport:
-            logging.debug("Activate the bug reporter")
+        if enable:
+            logging.debug("Bug reporter enabled")
 
             def log_uncaught_exceptions(exceptionClass, exceptionInstance, traceback):
                 bugReporterController = BugReporterController(self,
@@ -126,37 +148,10 @@ class NetzobMainController(object):
                 bugReporterController.run()
 
             sys.excepthook = log_uncaught_exceptions
+
         else:
-            logging.debug("Bug reporter not requested.")
-
-    def _loadWorkspace(self, opts):
-        logging.debug("+ Load workspace...")
-        if opts.workspace is None:
-            workspaceDir = ResourcesConfiguration.getWorkspaceDir()
-        else:
-            workspaceDir = opts.workspace
-
-        # Loading the workspace
-        workspace = (Workspace.loadWorkspace(workspaceDir))
-        if workspace is None:
-            # We force the creation (or specification) of the workspace
-            logging.info("Workspace not found: we ask to the user its new Netzob home directory")
-            workspaceDir = self.askForWorkspaceDir()
-            if workspaceDir is None:
-                logging.fatal("Stopping the execution (no workspace computed)!")
-                sys.exit()
-            else:
-                ResourcesConfiguration.generateUserFile(workspaceDir)
-                workspace = (Workspace.loadWorkspace(workspaceDir))
-        return workspace
-
-    def askForWorkspaceDir(self):
-        workspaceSelector = WorkspaceSelector()
-        workspaceSelector.run()
-        workspacePath = workspaceSelector.selectedWorkspace
-        if workspacePath is not None:
-            ResourcesConfiguration.createWorkspace(workspacePath)
-        return workspacePath
+            logging.debug("Bug reporter disabled.")
+            sys.excepthook = sys.__excepthook__
 
     def _initResourcesAndLocales(self):
         # Initialize resources
@@ -178,7 +173,7 @@ class NetzobMainController(object):
 
     def _initLogging(self, opts):
         # Create the logging infrastructure
-        LoggingConfiguration().initializeLogging(self.currentWorkspace, opts)
+        LoggingConfiguration(self.currentWorkspace, opts)
         self.log = logging.getLogger(__name__)
 
     def run(self):
@@ -190,7 +185,7 @@ class NetzobMainController(object):
         workspace before stopping the GTK"""
 
         result = self.closeCurrentProject()
-        if result == True:
+        if result:
             # Save the workspace
             self.getCurrentWorkspace().saveConfigFile()
 
@@ -325,182 +320,38 @@ class NetzobMainController(object):
     def saveProject_activate_cb(self, action):
         """Save the current project"""
 
-        if self.getCurrentProject() == None:
+        if self.getCurrentProject() is None:
             NetzobErrorMessage(_("No project selected."), self.view.mainWindow)
             return
         self.getCurrentProject().saveConfigFile(self.getCurrentWorkspace())
 
-    def fileSetFileChooser_importProject_cb(self, widget, applyButton):
-        """Callback executed when the user selects a file in the file
-        chooser of the import project dialog box"""
-
-        selectedFile = widget.get_filename()
-        if selectedFile is not None:
-            applyButton.set_sensitive(True)
-        else:
-            applyButton.set_sensitive(False)
-
     def importProject_activate_cb(self, action):
         """Display the dialog in order to import a project when the
         user request it through the menu."""
 
         logging.debug("Import project")
-        finish = False
-        errorMessage = None
 
-        while not finish:
-            # Open Dialogbox
-            builder2 = Gtk.Builder()
-            builder2.add_from_file(os.path.join(ResourcesConfiguration.getStaticResources(), "ui", "dialogbox.glade"))
-            dialog = builder2.get_object("importProject")
-            dialog.set_transient_for(self.view.mainWindow)
-
-            # Disable the apply button if no file is provided
-            applybutton = builder2.get_object("importProjectApplyButton")
-            fileChooserButton = builder2.get_object("importProjectFileChooserButton")
-            fileChooserButton.connect("file-set", self.fileSetFileChooser_importProject_cb, applybutton)
-
-            if errorMessage is not None:
-                # Display a warning message on the dialog box
-                warnLabel = builder2.get_object("importProjectWarnLabel")
-                warnLabel.set_text(errorMessage)
-                warnBox = builder2.get_object("importProjectWarnBox")
-                warnBox.show_all()
-
-            # Run the dialog window and wait for the result
-            result = dialog.run()
-
-            if result == 0:
-                selectedFile = fileChooserButton.get_filename()
-                dialog.destroy()
-
-                if selectedFile is None:
-                    errorMessage = _("No file selected")
-                else:
-                    # Verify the file is a valid definition of a project
-                    if Project.loadProjectFromFile(selectedFile) is None:
-                        errorMessage = _("The file doesn't define a valid project.")
-                    else:
-                        # Generate the Unique ID of the imported project
-                        idProject = str(uuid.uuid4())
-
-                        # First we verify and create if necessary the directory of the project
-                        projectPath = "projects/" + idProject + "/"
-                        destPath = os.path.join(os.path.join(self.getCurrentWorkspace().getPath(), projectPath))
-                        if not os.path.exists(destPath):
-                            logging.info("Creation of the directory " + destPath)
-                            os.mkdir(destPath)
-                        try:
-                            # Retrieving and storing of the config file
-                            destFile = os.path.join(destPath, Project.CONFIGURATION_FILENAME)
-                            shutil.copy(selectedFile, destFile)
-
-                            project = Project.loadProject(self.getCurrentWorkspace(), destPath)
-                            project.setID(idProject)
-                            project.setName(_("Copy of {0}").format(project.getName()))
-                            project.setPath(projectPath)
-                            project.saveConfigFile(self.getCurrentWorkspace())
-                            self.getCurrentWorkspace().referenceProject(project.getPath())
-                            self.getCurrentWorkspace().saveConfigFile()
-                            self.updateListOfAvailableProjects()
-                            finish = True
-                            errorMessage = None
-                        except IOError, e:
-                            errorMessage = _("An error occurred while copying the file")
-                            logging.warn("Error when importing project: {0}".format(e))
-            else:
-                dialog.destroy()
-                finish = True
-
-    def fileSetFileChooserOrFilenamEntry_exportProject_cb(self, widget, fileChooser, fileEntry, applyButton):
-        """Callback executed when the user selects a file in the file
-        chooser of the export project dialog box"""
-
-        currentFolder = fileChooser.get_current_folder()
-        currentFile = fileEntry.get_text()
-
-        if currentFolder is not None and len(currentFolder) > 0 and currentFile is not None and len(currentFile) > 0:
-            applyButton.set_sensitive(True)
-        else:
-            applyButton.set_sensitive(False)
+        controller = ProjectImportController(self)
+        controller.run()
 
     def xmlExportProject_activate_cb(self, action):
         """Display the dialog in order to export the current project
         when the user request it through the menu."""
 
-        if self.getCurrentProject() == None:
+        if self.getCurrentProject() is None:
             NetzobErrorMessage(_("No project selected."), self.view.mainWindow)
             return
 
         logging.debug("Export project")
 
-        finish = False
-        errorMessage = None
-        while not finish:
-            #open dialogbox
-            builder2 = Gtk.Builder()
-            builder2.add_from_file(os.path.join(ResourcesConfiguration.getStaticResources(), "ui", "dialogbox.glade"))
-            dialog = builder2.get_object("exportProject")
-            dialog.set_transient_for(self.view.mainWindow)
-
-            applybutton = builder2.get_object("exportProjectApplyButton")
-            filenameEntry = builder2.get_object("exportProjectFilenameEntry")
-            fileChooserButton = builder2.get_object("exportProjectFileChooserButton")
-
-            # Set the default filename based on current project
-            if self.getCurrentProject() is not None:
-                filenameEntry.set_text("{0}.xml".format(self.getCurrentProject().getName()))
-            else:
-                errorMessage = _("Please open a project before exporting it.")
-
-            fileChooserButton.connect("current-folder-changed", self.fileSetFileChooserOrFilenamEntry_exportProject_cb, fileChooserButton, filenameEntry, applybutton)
-            filenameEntry.connect("changed", self.fileSetFileChooserOrFilenamEntry_exportProject_cb, fileChooserButton, filenameEntry, applybutton)
-
-            # Execute the CB in case default case is functionnal
-            self.fileSetFileChooserOrFilenamEntry_exportProject_cb(fileChooserButton, fileChooserButton, filenameEntry, applybutton)
-
-            if errorMessage is not None:
-                # Display a warning message on the dialog box
-                warnLabel = builder2.get_object("exportProjectWarnLabel")
-                warnLabel.set_text(errorMessage)
-                warnBox = builder2.get_object("exportProjectWarnBox")
-                warnBox.show_all()
-
-            result = dialog.run()
-
-            if result == 0:
-                selectedFolder = fileChooserButton.get_current_folder()
-                filename = filenameEntry.get_text()
-                dialog.destroy()
-
-                if selectedFolder is None:
-                    errorMessage = _("No directory selected")
-                elif filename is None or len(filename) == 0:
-                    errorMessage = _("No filename provided")
-                else:
-                    if self.getCurrentProject() is None:
-                        errorMessage = _("Please open a project before exporting it.")
-                    else:
-                        try:
-                            outputFilename = os.path.join(selectedFolder, filename)
-                            logging.debug("Output filename: {0}".format(outputFilename))
-                            xmlDefinitionOfProject = self.getCurrentProject().generateXMLConfigFile()
-                            tree = ElementTree(xmlDefinitionOfProject)
-                            tree.write(outputFilename)
-                            finish = True
-                            errorMessage = None
-                        except IOError, e:
-                            errorMessage = _("An error occurred while exporting the project.")
-                            logging.warn("Error when importing project: {0}".format(e))
-            else:
-                dialog.destroy()
-                finish = True
+        controller = ProjectExportController(self)
+        controller.run()
 
     def rawExportProject_activate_cb(self, action):
         """Display the dialog in order to export the symbols when the
         user request it through the menu."""
 
-        if self.getCurrentProject() == None:
+        if self.getCurrentProject() is None:
             NetzobErrorMessage(_("No project selected."), self.view.mainWindow)
             return
         logging.debug("Export raw symbols")
@@ -516,6 +367,20 @@ class NetzobMainController(object):
         else:
             applyButton.set_sensitive(False)
 
+    def configureWorkspace_activate_cb(self, action):
+        """Callback executed when the user requests to configure the
+        current workspace"""
+
+        controller = WorkspaceConfigurationController(self)
+        controller.run()
+
+    def projectProperties_activate_cb(self, action):
+        """Callback executed when the user requests to update the
+        project properties"""
+
+        controller = ProjectPropertiesController(self, project=self.currentProject)
+        controller.run()
+
     def switchWorkspace_activate_cb(self, action):
         """Callback executed when the user requests to switch to
         another workspace"""
@@ -559,7 +424,7 @@ class NetzobMainController(object):
                         errorMessage = Workspace.isFolderAValidWorkspace(selectedFolder)
                         if errorMessage is None:
                             try:
-                                self.currentWorkspace = (Workspace.loadWorkspace(selectedFolder))
+                                (self.currentWorkspace, error) = (Workspace.loadWorkspace(selectedFolder))
                                 self.currentProject = self.currentWorkspace.getLastProject()
                                 finish = True
                                 errorMessage = None
@@ -575,8 +440,8 @@ class NetzobMainController(object):
                             errorMessage = None
                             self.view.currentWorkspaceHasChanged()
                         except Exception, e:
-                                errorMessage = _("An error occurred while creating workspace.")
-                                logging.warn("Error while creating workspace declared in folder {0}: {1}".format(selectedFolder, e))
+                            errorMessage = _("An error occurred while creating workspace.")
+                            logging.warn("Error while creating workspace declared in folder {0}: {1}".format(selectedFolder, e))
             else:
                 dialog.destroy()
                 finish = True
