@@ -95,6 +95,9 @@ class VocabularyController(object):
         """Activate the perspective"""
         # Refresh list of available exporter plugins
         self.updateListOfCapturerPlugins()
+        self.view.updateLeftPanel()
+
+    def deactivate(self):
         pass
 
     def restart(self):
@@ -386,6 +389,7 @@ class VocabularyController(object):
             self.view.updateLeftPanel()
 
     def split_activate_cb(self, action):
+        self.log.debug("Split field action requested by user")
         # Sanity check
         if self.getCurrentProject() is None:
             NetzobErrorMessage(_("No project selected."))
@@ -396,7 +400,7 @@ class VocabularyController(object):
 #            return
         fields = self.view.selectedMessageTable.treeViewHeaderGroup.getSelectedFields()
         # Split field
-        if fields != None and len(fields) > 0:
+        if fields is not None and len(fields) > 0:
             field = fields[-1]  # We take the last selected field
             controller = SplitFieldController(self, field)
             controller.run()
@@ -485,7 +489,7 @@ class VocabularyController(object):
         """Callback executed when the user clicks
         on the research toggle button"""
         if self.getCurrentProject() is None:
-            if action.get_active() == True:
+            if action.get_active():
                 NetzobErrorMessage(_("No project selected."))
             action.set_active(False)
             return
@@ -498,7 +502,7 @@ class VocabularyController(object):
         """Callback executed when the user clicks
         on the filter messages toggle button"""
         if self.getCurrentProject() is None:
-            if action.get_active() == True:
+            if action.get_active():
                 NetzobErrorMessage(_("No project selected."))
             action.set_active(False)
             return
